==> isopam_1.1.0.tar.gz: isopam/man/isotab.Rd <==
\encoding{UTF-8}
\name{isotab}
\Rdversion{1.1}
\alias{isotab}
\title{
Ordered frequency table for Isopam clusters
}
\description{
Computes an ordered frequency table based on Isopam clustering results. 
The upper part of the table lists typical descriptors (usually species) with
a significant binding to single clusters (according to customisable thresholds). 
The lower part of the table is ordered by descending overall frequency.  
}
\usage{
isotab(ip, level = 1, phi.min = 'auto', p.max = .05, wordy = FALSE)
}
\arguments{
  \item{ip}{
   object of class \code{isopam}.
}
  \item{level}{
   level in cluster hierarchy starting with 1 = first division.
}
  \item{phi.min}{
   threshold of \emph{phi} determining which descriptors (species) 
   are listed in the upper part of the table. Applies only to 
   descriptors passing the criterion defined by \code{p.max}. If
   \code{phi.min = 'auto'} (the default) isotab suggests a 
   suitable value based on the numbers of clusters, observations, 
   and descriptors.
}  
  \item{p.max}{
   threshold of Fisher's \emph{p} determining which descriptors 
   (species) are listed in the upper part of the table. Applies 
   only to descriptors passing the criterion defined by 
   \code{phi.min}.
}
  \item{wordy}{
   logical. If \code{TRUE} status messages and output tables are shown.
}

}
\details{
   \code{phi.min} is based on the standardized \emph{phi} value according to 
   \enc{Chitrý}{Chitry} et al. 2002.  
}
\value{
   \item{tab}{dataframe with ordered frequencies and their significance. 
   The latter is derived from Fisher's exact test (\emph{p} <= 0.05: *, 
   \emph{p} <= 0.01: **, \emph{p} <= 0.001: ***).}
   \item{n}{matrix with cluster sizes.}
   \item{thresholds}{\code{phi.min} and \code{p.max} used.} 
   \item{typical}{text with items (often species) typically 
     found in clusters (according to \code{thresholds}).}
   \item{typical_vector}{\code{typical} as a single character vector.}
   \item{isopam_indicators}{items (species) used as indicators in the
     original \code{isopam} clustering process.}

}
\references{
   \enc{Chitrý}{Chitry}, M., \enc{Tichý}{Tichy}, L., Holt, J., 
   \enc{Botta-Dukát}{Botta-Dukat}, Z. (2002): Determination of diagnostic 
   species with statistical fidelity measures. \emph{Journal of Vegetation 
   Science} \bold{13}, 79--90.

   Schmidtlein, S., \enc{Tichý}{Tichy}, L., Feilhauer, H., Faude, U.
   (2010): A brute force approach to vegetation classification.
   Journal of Vegetation Science (in press).
}
\author{
   Sebastian Schmidtlein
}

\seealso{
   \code{\link{isopam}}
}
\examples{
   ## load data to the current environment
   data(andechs)
     
   ## call isopam with the standard options
   ip<-isopam(andechs)
    
   ## build table (uppermost hierarchy level)
   isotab(ip)

   ## build table (lower hierarchy level)
   isotab(ip,2)
}

==> isopam_1.3.0.tar.gz: isopam/man/isotab.Rd <==
\encoding{UTF-8}
\name{isotab}
\Rdversion{1.1}
\alias{isotab}
\alias{print.isotab}
\title{
Ordered frequency table for Isopam clusters
}
\description{
Computes an ordered frequency table based on Isopam clustering results. 
The upper part of the table lists typical descriptors (usually species) with
a significant binding to individual clusters (according to customisable thresholds). 
The lower part of the table is ordered by descending overall frequency.  
}
\usage{
isotab(ip, level = NULL, phi.min = 'auto', p.max = .05, wordy = FALSE)
\method{print}{isotab}(x, \dots)
}
\arguments{
  \item{ip}{
   object of class \code{isopam}.}
  \item{level}{
   level in cluster hierarchy starting with 1 = first division.}
  \item{phi.min}{
   threshold of \emph{phi} determining which descriptors (species) 
   are listed in the upper part of the table. Applies only to 
   descriptors passing the criterion defined by \code{p.max}. If
   \code{phi.min = 'auto'} (the default) isotab suggests a 
   suitable value based on the numbers of clusters, observations, 
   and descriptors.}  
  \item{p.max}{
   threshold of Fisher's \emph{p} determining which descriptors 
   (species) are listed in the upper part of the table. Applies 
   only to descriptors passing the criterion defined by 
   \code{phi.min}.}
  \item{wordy}{
   logical. If \code{TRUE} status messages are shown.}
  \item{x}{\code{isotab} result object in method 
   \code{print}.}
  \item{...}{other arguments used by \code{print}.}
}  
\details{
   \code{phi.min} is based on the standardized \emph{phi} value according to 
   \enc{Chitrý}{Chitry} et al. 2002.  
}
\value{
   \item{tab}{dataframe with ordered frequencies and their significance. 
   The latter is derived from Fisher's exact test (\emph{p} <= 0.05: *, 
   \emph{p} <= 0.01: **, \emph{p} <= 0.001: ***).}
   \item{phi}{dataframe with standardized phi values.} 
   \item{n}{matrix with cluster sizes.}
   \item{thresholds}{\code{phi.min} and \code{p.max} used for table sorting.} 
   \item{typical}{text with items (often species) typically 
     found in clusters (according to \code{thresholds}).}
   \item{typical_vector}{\code{typical} as a single character vector.}
   \item{isopam_indicators}{items (species) used as indicators in the
     original \code{isopam} clustering process.}
   \item{sorted_table}{original data but with variables (often species)
     sorted as in \code{tab} and observations sorted by cluster.}
}
\references{
   \enc{Chitrý}{Chitry}, M., \enc{Tichý}{Tichy}, L., Holt, J., 
   \enc{Botta-Dukát}{Botta-Dukat}, Z. (2002): Determination of diagnostic 
   species with statistical fidelity measures. \emph{Journal of Vegetation 
   Science} \bold{13}, 79--90.

   Schmidtlein, S., \enc{Tichý}{Tichy}, L., Feilhauer, H., Faude, U.
   (2010): A brute force approach to vegetation classification.
   Journal of Vegetation Science (in press).
}
\author{
   Sebastian Schmidtlein
}

\seealso{
   \code{\link{isopam}}
}
\examples{
   ## load data to the current environment
   data(andechs)
     
   ## call isopam with the standard options
   ip<-isopam(andechs)
   ip
    
   ## build table
   it <- isotab(ip)
   it
}
